@@ -604,7 +604,9 @@ This is a list of all the values from the <code><b><?php echo realpath($ini_file
     $_recursion_marker = krumo::_marker();
     if ($hive =& krumo::_hive($dummy)) {
       foreach($hive as $i=>$bee){
-        if (is_object($bee)) {
+        // skip closures set as properties
+        $closure_prototype = function(){};
+        if (is_object($bee) && !($bee instanceof $closure_prototype)) {
           unset($hive[$i]->$_recursion_marker);
           // DEVEL: changed 'else' to 'elseif' below
           } elseif (is_array($bee)) {
